pub struct ExploreSearch {
list: OnceCell<ListStore>,
search: RefCell<ExploreSearchData>,
next_batch: RefCell<Option<String>>,
loading_state: Cell<LoadingState>,
abort_handle: RefCell<Option<AbortHandle>>,
}Fields
list: OnceCell<ListStore>The list of public rooms for the current search.
search: RefCell<ExploreSearchData>The current search.
next_batch: RefCell<Option<String>>The next batch to continue the search, if any.
loading_state: Cell<LoadingState>The loading state of the list.
abort_handle: RefCell<Option<AbortHandle>>The abort handle for the current request.
Implementations
Sourceimpl ExploreSearch
impl ExploreSearch
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl ExploreSearch
impl ExploreSearch
Sourcefn list_owned(&self) -> ListStore
fn list_owned(&self) -> ListStore
The owned list of public rooms for the current search.
Sourcepub(super) fn set_search(&self, search: ExploreSearchData)
pub(super) fn set_search(&self, search: ExploreSearchData)
Set the current search.
Sourcefn set_loading_state(&self, state: LoadingState)
fn set_loading_state(&self, state: LoadingState)
Set the loading state.
Sourcepub(super) fn can_load_more(&self) -> bool
pub(super) fn can_load_more(&self) -> bool
Whether we can load more rooms with the current search.
Sourcepub(super) async fn load(&self, clear: bool)
pub(super) async fn load(&self, clear: bool)
Load rooms.
If clear is true, we start a new search and replace the list of
rooms, otherwise we use the next_batch and add more rooms.
Sourcefn add_rooms(
&self,
session: &Session,
search: &ExploreSearchData,
response: Response,
)
fn add_rooms( &self, session: &Session, search: &ExploreSearchData, response: Response, )
Add the rooms from the given response to this list.